@@ -165,6 +165,13 @@ class CLIPrinter(object):
         )
     )
 
+  @staticmethod
+  def print_dir(dir_name):
+    print("-----------------------------\t-----\t{}".format(
+            str(dir_name)
+        )
+    )
+
   @staticmethod
   def print_lifecycle(lifecycle):
     for action in lifecycle["rules"]:
@@ -413,12 +420,19 @@ list all buckets or objects in a bucket
     prefix = url.object_name() or url.object_dir() or ""
     bucket_name = url.bucket_name()
     try:
-      results = fds_client.list_all_objects(bucket_name, prefix, delimiter)
-      for result in results:
-        metadata = fds_client.get_object_metadata(
-            bucket_name, result.object_name
-        )
-        CLIPrinter.print_object(result.object_name, metadata, human)
+      results = fds_client.list_objects(bucket_name, prefix, delimiter)
+      while True:
+        for prefix in results.common_prefixes:
+          CLIPrinter.print_dir(prefix)
+        for fds_object in results.objects:
+          metadata = fds_client.get_object_metadata(
+              bucket_name, fds_object.object_name
+          )
+          CLIPrinter.print_object(fds_object.object_name, metadata, human)
+        if results.is_truncated:
+          results = fds_client.list_next_batch_of_objects(results)
+        else:
+          break
     except GalaxyFDSClientException as e:
       click.echo(str(e))
 
@@ -840,7 +854,7 @@ def sync(src, dst, autodetect_mimetype, concurrency, force):
           o_name = o_name[1:] if o_name.startswith("/") else o_name
           url = FDSURL(fds_prefix + src_bucket_name + "/" + o.object_name)
           if "/" not in o_name:
-            executor.submit(_download, url, dst)
+            executor.submit(_download, url, dst, force)
           elif url.is_object_url():
             o_file_name = o_name.split("/")[-1]
             o_dir = str(Path(dst) / o_name.split(o_file_name)[0])
