@@ -24,7 +24,9 @@ class FDSObjectMetadata(object):
     Common.MULITPART_UPLOAD_MODE,
     Common.PREVIOUS_VERSION_ID,
     Common.SERVER_SIDE_ENCRYPTION,
-    Common.STORAGE_CLASS
+    Common.STORAGE_CLASS,
+    Common.RESTORE_EXPIRY_DATE,
+    Common.ONGOING_RESTORE
   ]
 
   def __init__(self):
@@ -38,6 +40,10 @@ class FDSObjectMetadata(object):
     self._check_metadata(key)
     self.metadata.update({key: value})
 
+  def remove_header(self, key):
+    if key in self.metadata:
+      del self.metadata[key]
+
   def _check_metadata(self, key):
     is_valid = key.startswith(self.USER_DEFINED_METADATA_PREFIX)
 
